@@ -182,7 +182,7 @@ class Timer:
 
         """
         try:
-            with open(path, "r") as statfile:
+            with open(path) as statfile:
                 stats = statfile.read().split()
         except (FileNotFoundError, PermissionError) as e:
             # FileNotFoundError: bad PID, or no /proc support
@@ -854,7 +854,9 @@ def ensure_interruptible_after(seconds: float, max_wait_after_interrupt: float =
         sage: with ensure_interruptible_after(2) as data: interruptible_sleep(1r)
         Traceback (most recent call last):
         ...
-        RuntimeError: Function terminates early after 1.00... < 2.0000 seconds
+        RuntimeError: Function terminates early after ... < 2.0000 seconds
+        sage: data  # abs tol 0.1
+        {'alarm_raised': False, 'elapsed': 1.0}
         sage: with ensure_interruptible_after(1) as data: uninterruptible_sleep(2r)
         Traceback (most recent call last):
         ...
